@@ -76,6 +76,14 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(days=-14)).strftime("%Y-%m-%d")
         end_date = (today + relativedelta(days=-7)).strftime("%Y-%m-%d")
 
+    elif period_config == "l30d":
+        start_date = (today + relativedelta(days=-30)).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d")
+
+    elif period_config == "previous_l30d":
+        start_date = (today + relativedelta(days=-60)).strftime("%Y-%m-%d")
+        end_date = (today + relativedelta(days=-30)).strftime("%Y-%m-%d")
+
     elif period_config == "ly":
         start_date = (today + relativedelta(years=-1)).strftime("%Y-01-01")
         end_date = today.strftime("%Y-01-01")
